@@ -45,13 +45,10 @@ def deleteTestrunner(option, opt_str, value, parser):
     Base, mappers = getModel(engine)
     TR = mappers[0]
     session = create_session(engine)
-    for tr in session.query(TR).filter_by(id=value):
-        for run in tr.run:
-            for result in run.result:
-                session.delete(result)
-            session.delete(run)
-        session.delete(tr)
+    tr = session.query(TR).filter_by(id=value).one()
+    session.delete(tr)
     session.flush()
+    session.commit()
     print 'Testrunner deleted'
 
 def main():
