@@ -112,7 +112,7 @@ def db(results, options, tests_failed):
     if options.verbose:
         print 'Connection to %s' % options.dsn
 
-    engine = setup(options.dsn)
+    engine = setup(options.dsn, echo=False)
     Base, mappers = getModel(engine)
     Testrunner, Run, Result = mappers
     Session = sessionmaker(bind=engine)
@@ -163,14 +163,23 @@ def db(results, options, tests_failed):
                         logdata=open(results[k]['logfilepath']).read(),
                         ))
 
-    # prune runs older than 7 days
-    TR.run = [r for r in TR.run if (now - r.created).days < 7]
     TR.run.append(R)
     session.flush()
 
     # get hold of the id of the latest run
     run_id = max([run.id for run in TR.run])
     session.commit()
+    session.clear()
+
+    # prune runs older than 7 days
+    TR = session.query(Testrunner).filter_by(name=unicode(options.ident)).one()
+    for run in TR.run:
+        if (now - run.created).days  > 7:
+            for result in run.result:
+                session.delete(result)
+            session.delete(run)
+    session.flush()
+    session.commit()
 
     return testrunner_id, run_id
 
